@@ -52,27 +52,29 @@ class GUI(object):
 
     last_event = pygame.time.get_ticks()
 
-    def __init__(self, touchscreen):
+    def __init__(self, touchscreen, bright=None):
+        self._bright_level = self.BRIGHT_LEVEL if bright is None else bright
         self._touchscreen = touchscreen
         self._current_page = None
         self._first_page = None
-        self.faded = False
-        self.blacked = False
+        self._running = False
+        self._faded = False
+        self._blacked = False
 
         with open('/sys/class/backlight/rpi_backlight/max_brightness', 'r') as f:
             max_str = f.readline()
         self.max_brightness = min(int(max_str), 255)
-        self.set_brightness(self.BRIGHT_LEVEL)
+        self.set_brightness(self._bright_level)
 
     def reset_display(self):
         self.last_event = pygame.time.get_ticks()
 
-        if self.faded:
-            self.set_brightness(self.BRIGHT_LEVEL)
+        if self._faded:
+            self.set_brightness(self._bright_level)
             self.fade = False
-        if self.blacked:
+        if self._blacked:
             self.set_light(True)
-            self.blacked = False
+            self._blacked = False
 
     def set_brightness(self, level):
         level_str = f"{min(self.max_brightness, level)}\n"
@@ -92,6 +94,7 @@ class GUI(object):
     def run(self, page):
         self._current_page = page
         self._first_page = page
+        self._running = True
 
         self._touchscreen.run()
 
@@ -113,24 +116,26 @@ class GUI(object):
             touch.on_move = handle_touches
 
         try:
-            while True:
+            while self._running:
                 time = pygame.time.get_ticks()
                 # deltaTime in seconds.
                 deltaTime = (time - self.last_event) / 1000.0
                 if deltaTime > self.BLACKOUT_TIME:
                     self.set_light(False)
-                    self.blacked = True
+                    self._blacked = True
                 elif deltaTime > self.FADE_TIME:
                     self.set_brightness(self.FADE_LEVEL)
-                    self.faded = True
+                    self._faded = True
 
                 self._current_page.render(self._touchscreen.surface)
                 pygame.display.flip()
                 fpsClock.tick(60)
-        except (KeyboardInterrupt, Exception) as e:
+        finally:
             self.reset_display()
-            print(f"Received exception {type(e)!r}: {e}")
             print("Stopping touchscreen thread...")
             self._touchscreen.stop()
             print("Exiting GUI...")
             exit()
+
+    def stop(self):
+        self._running = False
